@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.2 $
- * $Date: 2009/09/30 23:25:59 $
+ * $Revision: 4074 $
+ * $Date: 2014-04-23 14:13:52 -0700 (Wed, 23 Apr 2014) $
  * -----------------------------------------------------------------
  * Programmer(s): Allan Taylor, Alan Hindmarsh and
  *                Radu Serban @ LLNL
@@ -305,7 +305,7 @@ static void PrintHeader(realtype rtol, realtype atol)
 #if defined(SUNDIALS_EXTENDED_PRECISION) 
   printf("Tolerance parameters:  rtol = %Lg   atol = %Lg\n", rtol, atol);
 #elif defined(SUNDIALS_DOUBLE_PRECISION) 
-  printf("Tolerance parameters:  rtol = %lg   atol = %lg\n", rtol, atol);
+  printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #else
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #endif
@@ -315,7 +315,7 @@ static void PrintHeader(realtype rtol, realtype atol)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("IDACalcIC called with input boundary values = %Lg \n",BVAL);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("IDACalcIC called with input boundary values = %lg \n",BVAL);
+  printf("IDACalcIC called with input boundary values = %g \n",BVAL);
 #else
   printf("IDACalcIC called with input boundary values = %g \n",BVAL);
 #endif
@@ -357,7 +357,7 @@ static void PrintOutput(void *mem, realtype t, N_Vector uu)
   printf(" %5.2Lf %13.5Le  %d  %3ld  %3ld  %3ld  %4ld  %4ld  %9.2Le \n",
          t, umax, kused, nst, nni, nje, nre, nreLS, hused);
 #elif defined(SUNDIALS_DOUBLE_PRECISION) 
-  printf(" %5.2f %13.5le  %d  %3ld  %3ld  %3ld  %4ld  %4ld  %9.2le \n",
+  printf(" %5.2f %13.5e  %d  %3ld  %3ld  %3ld  %4ld  %4ld  %9.2e \n",
          t, umax, kused, nst, nni, nje, nre, nreLS, hused);
 #else
   printf(" %5.2f %13.5e  %d  %3ld  %3ld  %3ld  %4ld  %4ld  %9.2e \n",
