@@ -326,7 +326,7 @@ int main(int argc, char *argv[])
   PrintOutput(mem, uv, tret, data, comm);
 
   /* Print each PE's portion of the solution in a separate file. */
-  //PrintSol(mem, uv, uvp, data, comm);
+  /* PrintSol(mem, uv, uvp, data, comm); */
 
   /* On PE 0, print final set of statistics. */  
   if (thispe == 0)  {
@@ -628,13 +628,13 @@ static void PrintHeader(int SystemSize, int maxl,
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("Tolerance parameters:  rtol = %Lg   atol = %Lg\n", rtol, atol);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("Tolerance parameters:  rtol = %lg   atol = %lg\n", rtol, atol);
+  printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #else
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #endif
   printf("Linear solver: IDASPGMR     Max. Krylov dimension maxl: %d\n", maxl);
   printf("Preconditioner: band-block-diagonal (IDABBDPRE), with parameters\n");
-  printf("     mudq = %d,  mldq = %d,  mukeep = %d,  mlkeep = %d\n",
+  printf("     mudq = %ld,  mldq = %ld,  mukeep = %ld,  mlkeep = %ld\n",
          mudq, mldq, mukeep, mlkeep);
 
   printf("-----------------------------------------------------------\n");
@@ -691,10 +691,10 @@ static void PrintOutput(void *mem, N_Vector uv, realtype tt,
     for (i=1;i<NUM_SPECIES;i++)
       printf("         %12.4Le %12.4Le   |\n",cdata[i],clast[i]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-    printf("%8.2le %12.4le %12.4le   | %3ld  %1d %12.4le\n", 
+    printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", 
          tt, cdata[0], clast[0], nst, kused, hused);
     for (i=1;i<NUM_SPECIES;i++)
-      printf("         %12.4le %12.4le   |\n",cdata[i],clast[i]);
+      printf("         %12.4e %12.4e   |\n",cdata[i],clast[i]);
 #else
     printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", 
          tt, cdata[0], clast[0], nst, kused, hused);
@@ -749,7 +749,7 @@ static void PrintSol(void* mem, N_Vector uv, N_Vector uvp,
                (i)*NUM_SPECIES + (j)*NSMXSUB*npex);
         
       uvxy  = IJ_Vptr(uv, ix, jy);
-      //uvxy = (&NV_Ith_P(uv, (i)*NUM_SPECIES + (j)*NSMXSUB*npex ));
+      /* uvxy = (&NV_Ith_P(uv, (i)*NUM_SPECIES + (j)*NSMXSUB*npex )); */
       fprintf(fout, "%g\n%g\n", uvxy[0], uvxy[1]);
     }
   }    
@@ -1432,7 +1432,7 @@ static int resBlocal(long int Nlocal, realtype tt,
         rrBxy[is] = uvpBxy[is] + eps[is]*( (dcxui-dcxli)/dx2 + (dcyui-dcyli)/dy2 );
       }
 
-      //now add rates
+      /* now add rates */
       rrBxy[0] += (uvBxy[0]-uvBxy[1])*(2*uvxy[0]*uvxy[1] - B) - uvBxy[0]; 
       rrBxy[1] += uvxy[0]*uvxy[0]*(uvBxy[0]-uvBxy[1]);
     }
