@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.2 $
- * $Date: 2010/12/01 23:06:37 $
+ * $Revision: 4396 $
+ * $Date: 2015-02-26 16:59:39 -0800 (Thu, 26 Feb 2015) $
  * -----------------------------------------------------------------
  * Programmer(s): Allan Taylor, Alan Hindmarsh and
  *                Radu Serban @ LLNL
@@ -519,7 +519,7 @@ static void PrintHeader(int SystemSize, int maxl,
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("Tolerance parameters:  rtol = %Lg   atol = %Lg\n", rtol, atol);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("Tolerance parameters:  rtol = %lg   atol = %lg\n", rtol, atol);
+  printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #else
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #endif
@@ -582,10 +582,10 @@ static void PrintOutput(void *mem, N_Vector cc, realtype tt,
     for (i=1;i<NUM_SPECIES;i++)
       printf("         %12.4Le %12.4Le   |\n",cdata[i],clast[i]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-    printf("%8.2le %12.4le %12.4le   | %3ld  %1d %12.4le\n", 
+    printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", 
          tt, cdata[0], clast[0], nst, kused, hused);
     for (i=1;i<NUM_SPECIES;i++)
-      printf("         %12.4le %12.4le   |\n",cdata[i],clast[i]);
+      printf("         %12.4e %12.4e   |\n",cdata[i],clast[i]);
 #else
     printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", 
          tt, cdata[0], clast[0], nst, kused, hused);
