@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.2 $
- * $Date: 2010/12/01 23:06:38 $
+ * $Revision: 4396 $
+ * $Date: 2015-02-26 16:59:39 -0800 (Thu, 26 Feb 2015) $
  * -----------------------------------------------------------------
  * Programmer(s): Radu Serban @ LLNL
  * -----------------------------------------------------------------
@@ -762,7 +762,7 @@ static void PrintHeader(int Neq, realtype rtol, realtype atol,
 #if defined(SUNDIALS_EXTENDED_PRECISION)
     printf("Tolerance parameters:  rtol = %Lg   atol = %Lg\n", rtol, atol);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-    printf("Tolerance parameters:  rtol = %lg   atol = %lg\n", rtol, atol);
+    printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #else
     printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #endif
@@ -837,7 +837,7 @@ static void PrintOutput(int id, void *mem, realtype t, N_Vector uu,
     printf(" %5.2Lf %13.5Le  %d  %3ld  %3ld  %3ld  %4ld %4ld %4ld %9.2Le  %3ld %3ld\n",
            t, umax, kused, nst, nni, nli, nre, nreLS, nge, hused, npe, nps);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-    printf(" %5.2f %13.5le  %d  %3ld  %3ld  %3ld  %4ld %4ld %4ld %9.2le  %3ld %3ld\n",
+    printf(" %5.2f %13.5e  %d  %3ld  %3ld  %3ld  %4ld %4ld %4ld %9.2e  %3ld %3ld\n",
            t, umax, kused, nst, nni, nli, nre, nreLS, nge, hused, npe, nps);
 #else
     printf(" %5.2f %13.5e  %d  %3ld  %3ld  %3ld  %4ld %4ld %4ld %9.2e  %3ld %3ld\n",
@@ -853,7 +853,7 @@ static void PrintOutput(int id, void *mem, realtype t, N_Vector uu,
 #if defined(SUNDIALS_EXTENDED_PRECISION)
         printf("       %13.5Le\n", umax);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-        printf("       %13.5le\n", umax);
+        printf("       %13.5e\n", umax);
 #else
         printf("       %13.5e\n", umax);
 #endif
