@@ -1,7 +1,7 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.2 $
- * $Date: 2008/04/15 16:37:37 $
+ * $Revision: 4074 $
+ * $Date: 2014-04-23 14:13:52 -0700 (Wed, 23 Apr 2014) $
  * -----------------------------------------------------------------
  * Programmer(s): Cosmin Petra and Radu Serban @ LLNL
  * -----------------------------------------------------------------
@@ -123,6 +123,8 @@ int main(int argc, char *argv[])
   booleantype sensi, err_con;
   int sensi_meth;
 
+  N_Vector yQ, *yQS;
+
   ida_mem = NULL;
   data    = NULL;
   y       =  NULL;
@@ -243,7 +245,6 @@ int main(int argc, char *argv[])
   /*----------------------------------------------------------
    *               Q U A D R A T U R E S
    * ---------------------------------------------------------*/
-  N_Vector yQ, *yQS;
   yQ = N_VNew_Serial(2);
 
   Ith(yQ,1) = 0;
@@ -517,7 +518,7 @@ static void PrintIC(N_Vector y, N_Vector yp)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", data[0], data[1], data[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", data[0], data[1], data[2]);
+  printf("%12.4e %12.4e %12.4e \n", data[0], data[1], data[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", data[0], data[1], data[2]);
 #endif
@@ -527,7 +528,7 @@ static void PrintIC(N_Vector y, N_Vector yp)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", data[0], data[1], data[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", data[0], data[1], data[2]);
+  printf("%12.4e %12.4e %12.4e \n", data[0], data[1], data[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", data[0], data[1], data[2]);
 #endif
@@ -544,7 +545,7 @@ static void PrintSensIC(N_Vector y, N_Vector yp, N_Vector* yS, N_Vector* ypS)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", sdata[0], sdata[1], sdata[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", sdata[0], sdata[1], sdata[2]);
+  printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #endif
@@ -553,7 +554,7 @@ static void PrintSensIC(N_Vector y, N_Vector yp, N_Vector* yS, N_Vector* ypS)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", sdata[0], sdata[1], sdata[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", sdata[0], sdata[1], sdata[2]);
+  printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #endif
@@ -565,7 +566,7 @@ static void PrintSensIC(N_Vector y, N_Vector yp, N_Vector* yS, N_Vector* ypS)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", sdata[0], sdata[1], sdata[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", sdata[0], sdata[1], sdata[2]);
+  printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #endif
@@ -574,7 +575,7 @@ static void PrintSensIC(N_Vector y, N_Vector yp, N_Vector* yS, N_Vector* ypS)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", sdata[0], sdata[1], sdata[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", sdata[0], sdata[1], sdata[2]);
+  printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #endif
@@ -586,7 +587,7 @@ static void PrintSensIC(N_Vector y, N_Vector yp, N_Vector* yS, N_Vector* ypS)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", sdata[0], sdata[1], sdata[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", sdata[0], sdata[1], sdata[2]);
+  printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #endif
@@ -595,7 +596,7 @@ static void PrintSensIC(N_Vector y, N_Vector yp, N_Vector* yS, N_Vector* ypS)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", sdata[0], sdata[1], sdata[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", sdata[0], sdata[1], sdata[2]);
+  printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #endif
@@ -625,7 +626,7 @@ static void PrintOutput(void *ida_mem, realtype t, N_Vector u)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%8.3Le %2d  %8.3Le %5ld\n", t, qu, hu, nst);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%8.3le %2d  %8.3le %5ld\n", t, qu, hu, nst);
+  printf("%8.3e %2d  %8.3e %5ld\n", t, qu, hu, nst);
 #else
   printf("%8.3e %2d  %8.3e %5ld\n", t, qu, hu, nst);
 #endif
@@ -635,7 +636,7 @@ static void PrintOutput(void *ida_mem, realtype t, N_Vector u)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", udata[0], udata[1], udata[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", udata[0], udata[1], udata[2]);
+  printf("%12.4e %12.4e %12.4e \n", udata[0], udata[1], udata[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", udata[0], udata[1], udata[2]);
 #endif
@@ -656,7 +657,7 @@ static void PrintSensOutput(N_Vector *uS)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", sdata[0], sdata[1], sdata[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", sdata[0], sdata[1], sdata[2]);
+  printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #endif
@@ -667,7 +668,7 @@ static void PrintSensOutput(N_Vector *uS)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", sdata[0], sdata[1], sdata[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", sdata[0], sdata[1], sdata[2]);
+  printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #endif
@@ -678,7 +679,7 @@ static void PrintSensOutput(N_Vector *uS)
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%12.4Le %12.4Le %12.4Le \n", sdata[0], sdata[1], sdata[2]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("%12.4le %12.4le %12.4le \n", sdata[0], sdata[1], sdata[2]);
+  printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #else
   printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #endif
