@@ -1,7 +1,7 @@
       program fkinDiagon_kry
 c     ----------------------------------------------------------------
-c     $Revision: 1.2 $
-c     $Date: 2009/09/30 23:41:32 $
+c     $Revision: 4074 $
+c     $Date: 2014-04-23 14:13:52 -0700 (Wed, 23 Apr 2014) $
 c     ----------------------------------------------------------------
 c     Programmer(s): Allan Taylor, Alan Hindmarsh and
 c                    Radu Serban @ LLNL  
@@ -21,11 +21,11 @@ c     ----------------------------------------------------------------
 c
       implicit none
 
-      integer ier, globalstrat, maxl, maxlrst
-      integer*4 PROBSIZE
+      integer PROBSIZE
       parameter(PROBSIZE=128)
-      integer*4 neq, i, msbpre
-      integer*4 iout(15)
+c The following declaration specification should match C type long int.
+      integer*8 neq, iout(15), msbpre
+      integer ier, globalstrat, maxl, maxlrst, i
       double precision pp, fnormtol, scsteptol
       double precision rout(2), uu(PROBSIZE), scale(PROBSIZE)
       double precision constr(PROBSIZE)
@@ -46,7 +46,7 @@ c * * * * * * * * * * * * * * * * * * * * * *
       call fnvinits(3, neq, ier)
       if (ier .ne. 0) then
          write(6,1220) ier
- 1220    format('SUNDIALS_ERROR: FNVINITS returned IER = ', i2)
+ 1220    format('SUNDIALS_ERROR: FNVINITS returned IER = ', i4)
          stop
       endif
 
@@ -59,19 +59,45 @@ c * * * * * * * * * * * * * * * * * * * * * *
       call fkinmalloc(iout, rout, ier)
       if (ier .ne. 0) then
          write(6,1230) ier
- 1230    format('SUNDIALS_ERROR: FKINMALLOC returned IER = ', i2)
+ 1230    format('SUNDIALS_ERROR: FKINMALLOC returned IER = ', i4)
          stop
       endif
 
       call fkinsetiin('MAX_SETUPS', msbpre, ier)
+      if (ier .ne. 0) then
+         write(6,1231) ier
+ 1231    format('SUNDIALS_ERROR: FKINSETIIN returned IER = ', i4)
+         call fkinfree
+         stop
+      endif
+
       call fkinsetrin('FNORM_TOL', fnormtol, ier)
+      if (ier .ne. 0) then
+         write(6,1232) ier
+ 1232    format('SUNDIALS_ERROR: FKINSETRIN returned IER = ', i4)
+         call fkinfree
+         stop
+      endif
+
       call fkinsetrin('SSTEP_TOL', scsteptol, ier)
+      if (ier .ne. 0) then
+         write(6,1232) ier
+         call fkinfree
+         stop
+      endif
+
       call fkinsetvin('CONSTR_VEC', constr, ier)
+      if (ier .ne. 0) then
+         write(6,1233) ier
+ 1233    format('SUNDIALS_ERROR: FKINSETVIN returned IER = ', i4)
+         call fkinfree
+         stop
+      endif
 
       call fkinspgmr(maxl, maxlrst, ier)
       if (ier .ne. 0) then
          write(6,1235) ier
- 1235    format('SUNDIALS_ERROR: FKINSPGMR returned IER = ', i2)
+ 1235    format('SUNDIALS_ERROR: FKINSPGMR returned IER = ', i4)
          call fkinfree
          stop
       endif
@@ -88,14 +114,14 @@ c * * * * * * * * * * * * * * * * * * * * * *
       call fkinsol(uu, globalstrat, scale, scale, ier)
       if (ier .lt. 0) then
          write(6,1242) ier, iout(9)
- 1242    format('SUNDIALS_ERROR: FKINSOL returned IER = ', i2, /,
-     1          '                Linear Solver returned IER = ', i2)
+ 1242    format('SUNDIALS_ERROR: FKINSOL returned IER = ', i4, /,
+     1          '                Linear Solver returned IER = ', i4)
          call fkinfree
          stop
       endif
 
       write(6,1245) ier
- 1245 format(/' FKINSOL return code is ', i3)
+ 1245 format(/' FKINSOL return code is ', i4)
 
       write(6,1246)
  1246 format(//' The resultant values of uu are:'/)
@@ -125,8 +151,9 @@ c     function of the following form.
 
       implicit none
 
-      integer ier
-      integer*4 neq, i
+      integer ier, i
+c The following declaration specification should match C type long int.
+      integer*8 neq
       double precision fval(*), uu(*)
 
       common /psize/ neq
@@ -146,13 +173,14 @@ c     The routine kpreco is the preconditioner setup routine. It must have
 c     that specific name be used in order that the c code can find and link
 c     to it.  The argument list must also be as illustrated below:
       
-      subroutine fkpset(udata, uscale, fdata, fscale, 
-     1                  vtemp1, vtemp2, ier)
+      subroutine fkpset(udata, uscale, fdata, fscale, vtemp1, vtemp2,
+     1                  ier)
 
       implicit none
 
-      integer ier
-      integer*4 neq, i
+      integer ier, i
+c The following declaration specification should match C type long int.
+      integer*8 neq
       double precision pp
       double precision udata(*), uscale(*), fdata(*), fscale(*)
       double precision vtemp1(*), vtemp2(*)
@@ -174,13 +202,13 @@ c     The routine kpsol is the preconditioner solve routine. It must have
 c     that specific name be used in order that the c code can find and link
 c     to it.  The argument list must also be as illustrated below:
       
-      subroutine fkpsol(udata, uscale, fdata, fscale, 
-     1                  vv, ftem, ier)
+      subroutine fkpsol(udata, uscale, fdata, fscale, vv, ftem, ier)
 
       implicit none
 
-      integer ier
-      integer*4 neq, i
+      integer ier, i
+c The following declaration specification should match C type long int.
+      integer*8 neq
       double precision pp
       double precision udata(*), uscale(*), fdata(*), fscale(*)
       double precision vv(*), ftem(*)
