@@ -1,15 +1,20 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.9 $
- * $Date: 2010/12/01 22:27:37 $
+ * $Revision: 4423 $
+ * $Date: 2015-03-08 17:23:10 -0700 (Sun, 08 Mar 2015) $
  * ----------------------------------------------------------------- 
  * Programmer(s): Alan C. Hindmarsh, Radu Serban and
  *                Aaron Collier @ LLNL
  * -----------------------------------------------------------------
- * Copyright (c) 2002, The Regents of the University of California.
+ * LLNS Copyright Start
+ * Copyright (c) 2014, Lawrence Livermore National Security
+ * This work was performed under the auspices of the U.S. Department 
+ * of Energy by Lawrence Livermore National Laboratory in part under 
+ * Contract W-7405-Eng-48 and in part under Contract DE-AC52-07NA27344.
  * Produced at the Lawrence Livermore National Laboratory.
  * All rights reserved.
  * For details, see the LICENSE file.
+ * LLNS Copyright End
  * -----------------------------------------------------------------
  * This is the header file for FCVODE, the Fortran interface to
  * the CVODE package.                                            
@@ -34,6 +39,8 @@
  * 
  *   FNVINITS and FNVINITP interface to N_VNew_Serial and
  *               N_VNew_Parallel, respectively
+ *   FNVINITOMP               N_VNew_OpenMP
+ *   FNVINITPTS               N_VNew_Pthreads
  * 
  *   FCVMALLOC  interfaces to CVodeCreate, CVodeSetUserData, and CVodeInit
  * 
@@ -56,6 +63,10 @@
  *   FCVLAPACKDENSESETJAC  interfaces to CVLapackSetJacFn
  *   FCVLAPACKBANDSETJAC   interfaces to CVLapackSetJacFn
  *
+ *   FCVKLU         interfaces to CVKLU
+ *   FCVKLUReinit   interfaces to CVKLUReinit
+ *   FCVSUPERLUMT   interfaces to CVSuperLUMT
+ *
  *   FCVSPGMR and FCVSPGMRREINIT interface to CVSpgmr and CVSpilsSet*
  *   FCVSPBCG, FCVSPBCGREINIT interface to CVSpbcg and CVSpilsSet*
  *   FCVSPTFQMR, FCVSPTFQMRREINIT interface to CVSptfqmr and CVSpilsSet*
@@ -83,6 +94,7 @@
  *   FCVPSOL   is called by the interface fn. FCVPSol of type CVSpilsPrecSolveFn
  *   FCVPSET   is called by the interface fn. FCVPSet of type CVSpilsPrecSetupFn
  *   FCVJTIMES is called by interface fn. FCVJtimes of type CVSpilsJacTimesVecFn
+ *   FCVSPJAC  is called by interface fn. FCVSparseJac of type CVSlsSparseJacFn
  *   FCVEWT    is called by interface fn. FCVEwtSet of type CVEwtFn
  * In contrast to the case of direct use of CVODE, and of most Fortran ODE
  * solvers, the names of all user-supplied routines here are fixed, in
@@ -153,15 +165,55 @@
  * On return, set IER = 0 if successful, IER > 0 if a recoverable error occurred,
  * and IER < 0 if an unrecoverable error ocurred.
  * 
- * (4s) Optional user-supplied Lapack dense Jacobian routine: FCVLDJAC
+ (4s) User-supplied sparse Jacobian approximation routine: FCVSPJAC
+
+     Required when using the CVKLU or CVSuperLUMT linear solvers, the 
+     user must supply a routine that computes a compressed-sparse-column 
+     approximation of the system Jacobian J = dfi(t,y)/dy.  If supplied, 
+     it must have the following form:
+
+       SUBROUTINE FCVSPJAC(T, Y, FY, N, NNZ, JDATA, JRVALS, 
+      &                     JCPTRS, H, IPAR, RPAR, WK1, WK2, WK3, IER)
+
+     This routine must load the N by N compressed sparse column matrix 
+     with storage for NNZ nonzeros, stored in the arrays JDATA (nonzero
+     values), JRVALS (row indices for each nonzero), JCOLPTRS (indices 
+     for start of each column), with the Jacobian matrix at the current
+     (t,y) in CSC form (see sundials_sparse.h for more information).
+
+     The arguments are:
+         T    -- current time [realtype, input]
+         Y    -- array containing state variables [realtype, input]
+         FY   -- array containing state derivatives [realtype, input]
+         N    -- number of matrix rows/columns in Jacobian [int, input]
+         NNZ  -- allocated length of nonzero storage [int, input]
+        JDATA -- nonzero values in Jacobian
+                 [realtype of length NNZ, output]
+       JRVALS -- row indices for each nonzero in Jacobian
+                  [int of length NNZ, output]
+       JCPTRS -- pointers to each Jacobian column in preceding arrays
+                 [int of length N+1, output]
+         H    -- current step size [realtype, input]
+         IPAR -- array containing integer user data that was passed to
+                 FCVMALLOC [long int, input]
+         RPAR -- array containing real user data that was passed to
+                 FCVMALLOC [realtype, input]
+         WK*  -- array containing temporary workspace of same size as Y 
+                 [realtype, input]
+         IER  -- return flag [int, output]:
+                    0 if successful, 
+                   >0 if a recoverable error occurred,
+                   <0 if an unrecoverable error ocurred.
+
+ * (5s) Optional user-supplied Lapack dense Jacobian routine: FCVLDJAC
  * See the description for FCVDJAC. NOTE: the dense Jacobian matrix
  * is NOT set to zero before calling the user's FCVLDJAC.
  *
- * (5s) Optional user-supplied Lapack band Jacobian routine: FCVLBJAC
+ * (6s) Optional user-supplied Lapack band Jacobian routine: FCVLBJAC
  * See the description for FCVBJAC. NOTE: the band Jacobian matrix
  * is NOT set to zero before calling the user's FCVLBJAC.
  *
- * (6) Optional user-supplied Jacobian-vector product routine: FCVJTIMES
+ * (7) Optional user-supplied Jacobian-vector product routine: FCVJTIMES
  * As an option when using the SP* linear solver, the user may supply
  * a routine that computes the product of the system Jacobian J = df/dy and 
  * a given vector v.  If supplied, it must have the following form:
@@ -173,7 +225,7 @@
  * and nonzero otherwise.
  * IPAR and RPAR are user (integer and real) arrays passed to FCVMALLOC.
  * 
- * (7) Optional user-supplied error weight vector routine: FCVEWT
+ * (8) Optional user-supplied error weight vector routine: FCVEWT
  * As an option to providing the relative and absolute tolerances, the user
  * may supply a routine that computes the weights used in the WRMS norms.
  * If supplied, it must have the following form:
@@ -185,17 +237,18 @@
  *
  * -----------------------------------------------------------------------------
  *
- * (8) Initialization:  FNVINITS / FNVINITP , FCVMALLOC, FCVREINIT
+ * (9) Initialization:  FNVINITS/FNVINITP/FNVINITOMP/FNVINITPTS, 
+ *                      FCVMALLOC, FCVREINIT
  * 
- * (8.1s) To initialize the serial machine environment, the user must make
+ * (9.1s) To initialize the serial machine environment, the user must make
  * the following call:
  *        CALL FNVINITS (1, NEQ, IER)
  * where the first argument is the CVODE solver ID. The other arguments are:
  * NEQ     = size of vectors
  * IER     = return completion flag. Values are 0 = success, -1 = failure.
  * 
- * (8.1p) To initialize the parallel machine environment, the user must make 
- * the following call:
+ * (9.1p) To initialize the distributed memory parallel machine environment, 
+ * the user must make the following call:
  *        CALL FNVINITP (1, NLOCAL, NGLOBAL, IER)
  * The arguments are:
  * NLOCAL  = local size of vectors on this processor
@@ -206,7 +259,27 @@
  * set to MPI_COMM_WORLD.  If not, this routine initializes MPI and sets
  * the communicator equal to MPI_COMM_WORLD.
  * 
- * (8.2) To set various problem and solution parameters and allocate
+ (9.1omp) To initialize the openMP threaded vector kernel, 
+          the user must make the following call:
+
+          CALL FNVINITOMP (1, NEQ, NUM_THREADS, IER)
+
+        The arguments are:
+          NEQ = size of vectors
+          NUM_THREADS = number of threads
+          IER = return completion flag. Values are 0 = success, -1 = failure.
+
+ (9.1pts) To initialize the Pthreads threaded vector kernel, 
+          the user must make the following call:
+
+          CALL FNVINITOMP (1, NEQ, NUM_THREADS, IER)
+
+        The arguments are:
+          NEQ = size of vectors
+          NUM_THREADS = number of threads
+          IER = return completion flag. Values are 0 = success, -1 = failure.
+
+ * (9.2) To set various problem and solution parameters and allocate
  * internal memory, make the following call:
  *       CALL FCVMALLOC(T0, Y0, METH, ITMETH, IATOL, RTOL, ATOL,
  *      1               IOUT, ROUT, IPAR, RPAR, IER)
@@ -262,7 +335,7 @@
  * with FLAG = 1 to specify that FCVEWT is provided.
  * The return flag IER is 0 if successful, and nonzero otherwise.
  *
- * (8.3) To re-initialize the CVODE solver for the solution of a new problem
+ * (9.3) To re-initialize the CVODE solver for the solution of a new problem
  * of the same size as one already solved, make the following call:
  *       CALL FCVREINIT(T0, Y0, IATOL, RTOL, ATOL, IER)
  * The arguments have the same names and meanings as those of FCVMALLOC,
@@ -273,7 +346,7 @@
  * previous  FCVMALLOC call.  The call to specify the linear system solution
  * method may or may not be needed; see paragraph (7) below.
  * 
- * (8.4) To set various integer optional inputs, make the folowing call:
+ * (9.4) To set various integer optional inputs, make the folowing call:
  *       CALL FCVSETIIN(KEY, VALUE, IER)
  * to set the integer value VAL to the optional input specified by the
  * quoted character string KEY.
@@ -292,14 +365,14 @@
  *
  * -----------------------------------------------------------------------------
  *
- * (9) Specification of linear system solution method.
+ * (10) Specification of linear system solution method.
  * In the case of a stiff system, the implicit BDF method involves the solution
  * of linear systems related to the Jacobian J = df/dy of the ODE system.
  * CVODE presently includes four choices for the treatment of these systems,
  * and the user of FCVODE must call a routine with a specific name to make the
  * desired choice.
  * 
- * (9.1) Diagonal approximate Jacobian.
+ * (10.1) Diagonal approximate Jacobian.
  * This choice is appropriate when the Jacobian can be well approximated by
  * a diagonal matrix.  The user must make the call:
  *       CALL FCVDIAG(IER)
@@ -313,7 +386,7 @@
  *        NFELS   = IOUT(16) from CVDiagGetNumRhsEvals
  * See the CVODE manual for descriptions.
  * 
- * (9.2s) DENSE treatment of the linear system.
+ * (10.2s) DENSE treatment of the linear system.
  * The user must make the call
  *       CALL FCVDENSE(NEQ, IER)
  * The argument is:
@@ -334,7 +407,7 @@
  *        NJED    = IOUT(17) from CVDenseGetNumJacEvals
  * See the CVODE manual for descriptions.
  * 
- * (9.3s) BAND treatment of the linear system
+ * (10.3s) BAND treatment of the linear system
  * The user must make the call
  *       CALL FCVBAND(NEQ, MU, ML, IER)
  * The arguments are:
@@ -357,7 +430,7 @@
  *        NJEB    = IOUT(17) from CVBandGetNumJacEvals
  * See the CVODE manual for descriptions.
  *
- * (9.4s) LAPACK dense treatment of the linear system
+ * (10.4s) LAPACK dense treatment of the linear system
  * The user must make the call
  *       CALL FCVLAPACKDENSE(NEQ, IER)
  * and, optionally
@@ -365,7 +438,7 @@
  * with FLAG=1 if the user provides the function FCVLDJAC. 
  * See (9.2s) for more details.
  *
- * (9.5s) LAPACK band treatment of the linear system
+ * (10.5s) LAPACK band treatment of the linear system
  * The user must make the call
  *       CALL FCVLAPACKBAND(NEQ, IER)
  * and, optionally
@@ -373,7 +446,77 @@
  * with FLAG=1 if the user provides the function FCVLBJAC. 
  * See (9.3s)
  *
- * (9.6) SPGMR treatment of the linear systems.
+  (10.6s) SPARSE treatment of the linear system using the KLU solver.
+
+     The user must make the call
+
+       CALL FCVKLU(NEQ, NNZ, ORDERING, IER)
+
+     The arguments are:
+        NEQ = the problem size [int; input]
+        NNZ = the maximum number of nonzeros [int; input]
+	ORDERING = the matrix ordering desired, possible values
+	   come from the KLU package (0 = AMD, 1 = COLAMD) [int; input]
+	IER = error return flag [int, output]: 
+	         0 = success, 
+		 negative = error.
+ 
+     The CVODE KLU solver will reuse much of the factorization information from one
+     nonlinear iteration to the next.  If at any time the user wants to force a full
+     refactorization or if the number of nonzeros in the Jacobian matrix changes, the
+     user should make the call
+
+       CALL FCVKLUREINIT(NEQ, NNZ, REINIT_TYPE)
+
+     The arguments are:
+        NEQ = the problem size [int; input]
+        NNZ = the maximum number of nonzeros [int; input]
+	REINIT_TYPE = 1 or 2.  For a value of 1, the matrix will be destroyed and 
+          a new one will be allocated with NNZ nonzeros.  For a value of 2, 
+	  only symbolic and numeric factorizations will be completed. 
+ 
+     When using FCVKLU, the user is required to supply the FCVSPJAC 
+     routine for the evaluation of the sparse approximation to the 
+     Jacobian, as discussed above with the other user-supplied routines.
+ 
+     Optional outputs specific to the KLU case are:
+        LSTF    = IOUT(14) from CVSlsGetLastFlag
+        NJES    = IOUT(16) from CVSlsGetNumJacEvals
+     See the CVODE manual for descriptions.
+ 
+ (10.7s) SPARSE treatment of the linear system using the SuperLUMT solver.
+
+     The user must make the call
+
+       CALL FCVSUPERLUMT(NTHREADS, NEQ, NNZ, ORDERING, IER)
+
+     The arguments are:
+        NTHREADS = desired number of threads to use [int; input]
+        NEQ = the problem size [int; input]
+        NNZ = the maximum number of nonzeros [int; input]
+	ORDERING = the matrix ordering desired, possible values
+	   come from the SuperLU_MT package [int; input]
+           0 = Natural
+           1 = Minimum degree on A^T A
+           2 = Minimum degree on A^T + A
+           3 = COLAMD
+	IER = error return flag [int, output]: 
+	         0 = success, 
+		 negative = error.
+	 
+     At this time, there is no reinitialization capability for the SUNDIALS 
+     interfaces to the SuperLUMT solver.
+
+     When using FCVSUPERLUMT, the user is required to supply the FCVSPJAC 
+     routine for the evaluation of the sparse approximation to the 
+     Jacobian, as discussed above with the other user-supplied routines.
+ 
+     Optional outputs specific to the SUPERLUMT case are:
+        LSTF    = IOUT(14) from CVSlsGetLastFlag
+        NJES    = IOUT(16) from CVSlsGetNumJacEvals
+     See the CVODE manual for descriptions.
+ 
+ * (10.8) SPGMR treatment of the linear systems.
  * For the Scaled Preconditioned GMRES solution of the linear systems,
  * the user must make the following call:
  *       CALL FCVSPGMR(IPRETYPE, IGSTYPE, MAXL, DELT, IER)              
@@ -411,7 +554,7 @@
  * The arguments have the same meanings as for FCVSPGMR.  If MAXL is being
  * changed, then call FCVSPGMR instead.
  * 
- * (9.7) SPBCG treatment of the linear systems.
+ * (10.9) SPBCG treatment of the linear systems.
  * For the Scaled Preconditioned Bi-CGSTAB solution of the linear systems,
  * the user must make the following call:
  *       CALL FCVSPBCG(IPRETYPE, MAXL, DELT, IER)              
@@ -444,7 +587,7 @@
  *       CALL FCVSPBCGREINIT(IPRETYPE, MAXL, DELT, IER)              
  * The arguments have the same meanings as for FCVSPBCG.
  *
- * (9.8) SPTFQMR treatment of the linear systems.
+ * (10.10) SPTFQMR treatment of the linear systems.
  * For the Scaled Preconditioned TFQMR solution of the linear systems,
  * the user must make the following call:
  *       CALL FCVSPTFQMR(IPRETYPE, MAXL, DELT, IER)              
@@ -477,7 +620,7 @@
  *       CALL FCVSPTFQMRREINIT(IPRETYPE, MAXL, DELT, IER)              
  * The arguments have the same meanings as for FCVSPTFQMR.
  *
- * (9.9) Usage of user-supplied routines for the Krylov solvers
+ * (10.11) Usage of user-supplied routines for the Krylov solvers
  *
  * If the user program includes the FCVJTIMES routine for the evaluation of the 
  * Jacobian vector product, the following call must be made
@@ -505,7 +648,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * (10) The integrator: FCVODE
+ * (11) The integrator: FCVODE
  * Carrying out the integration is accomplished by making calls as follows:
  *       CALL FCVODE (TOUT, T, Y, ITASK, IER)
  * The arguments are:
@@ -524,7 +667,7 @@
  * 
  * -----------------------------------------------------------------------------
  *
- * (11) Computing solution derivatives: FCVDKY
+ * (12) Computing solution derivatives: FCVDKY
  * To obtain a derivative of the solution, of order up to the current method
  * order, make the following call:
  *       CALL FCVDKY (T, K, DKY, IER)
@@ -536,7 +679,7 @@
  * 
  * -----------------------------------------------------------------------------
  *
- * (12) Memory freeing: FCVFREE 
+ * (13) Memory freeing: FCVFREE 
  * To free the internal memory created by the calls to FCVMALLOC and
  * FNVINITS or FNVINITP, make the call
  *       CALL FCVFREE
@@ -547,17 +690,17 @@
 #ifndef _FCVODE_H
 #define _FCVODE_H
 
+/* header files  */
+#include <cvode/cvode.h>
+#include <sundials/sundials_direct.h>  /* definition of type DlsMat   */
+#include <sundials/sundials_sparse.h>  /* definition of type SlsMat   */
+#include <sundials/sundials_nvector.h> /* definition of type N_Vector */
+#include <sundials/sundials_types.h>   /* definition of type realtype */
+
 #ifdef __cplusplus  /* wrapper to enable C++ usage */
 extern "C" {
 #endif
 
-/* header files  */
-
-#include <cvode/cvode.h>
-#include <sundials/sundials_direct.h>  /* definition of type DlsMat   */
-#include <sundials/sundials_nvector.h> /* definition of type N_Vector */
-#include <sundials/sundials_types.h>   /* definition of type realtype */
-
 /* Definitions of interface function names */
 
 #if defined(SUNDIALS_F77_FUNC)
@@ -576,6 +719,9 @@ extern "C" {
 #define FCV_LAPACKDENSESETJAC   SUNDIALS_F77_FUNC(fcvlapackdensesetjac, FCVLAPACKDENSESETJAC)
 #define FCV_LAPACKBAND     SUNDIALS_F77_FUNC(fcvlapackband, FCVLAPACKBAND)
 #define FCV_LAPACKBANDSETJAC    SUNDIALS_F77_FUNC(fcvlapackbandsetjac, FCVLAPACKBANDSETJAC)
+#define FCV_KLU            SUNDIALS_F77_FUNC(fcvklu, FCVKLU)
+#define FCV_KLUREINIT      SUNDIALS_F77_FUNC(fcvklureinit, FCVKLUREINIT)
+#define FCV_SUPERLUMT      SUNDIALS_F77_FUNC(fcvsuperlumt, FCVSUPERLUMT)
 #define FCV_SPTFQMR        SUNDIALS_F77_FUNC(fcvsptfqmr, FCVSPTFQMR)
 #define FCV_SPTFQMRREINIT  SUNDIALS_F77_FUNC(fcvsptfqmrreinit, FCVSPTFQMRREINIT)
 #define FCV_SPBCG          SUNDIALS_F77_FUNC(fcvspbcg, FCVSPBCG)
@@ -613,6 +759,9 @@ extern "C" {
 #define FCV_LAPACKDENSESETJAC   fcvlapackdensesetjac_
 #define FCV_LAPACKBAND     fcvlapackband_
 #define FCV_LAPACKBANDSETJAC    fcvlapackbandsetjac_
+#define FCV_KLU            fcvklu_
+#define FCV_KLUREINIT      fcvklureinit_
+#define FCV_SUPERLUMT      fcvsuperlumt_
 #define FCV_SPTFQMR        fcvsptfqmr_
 #define FCV_SPTFQMRREINIT  fcvsptfqmrreinit_
 #define FCV_SPBCG          fcvspbcg_
@@ -656,9 +805,9 @@ extern "C" {
                   int *iatol, realtype *rtol, realtype *atol,
                   int *ier);
 
-  void FCV_SETIIN(char key_name[], long int *ival, int *ier, int key_len);
+  void FCV_SETIIN(char key_name[], long int *ival, int *ier);
 
-  void FCV_SETRIN(char key_name[], realtype *rval, int *ier, int key_len);
+  void FCV_SETRIN(char key_name[], realtype *rval, int *ier);
 
   void FCV_EWTSET(int *flag, int *ier);
 
@@ -675,6 +824,10 @@ extern "C" {
   void FCV_LAPACKBAND(int *neq, int *mupper, int *mlower, int *ier);
   void FCV_LAPACKBANDSETJAC(int *flag, int *ier);
 
+  void FCV_KLU(int *neq, int *nnz, int *ordering, int *ier);
+  void FCV_KLUREINIT(int *neq, int *nnz, int *reinit_type, int *ier);
+  void FCV_SUPERLUMT(int *nthreads, int *neq, int *nnz, int *ordering, int *ier);
+
   void FCV_SPGMR(int *pretype, int *gstype, int *maxl, realtype *delt, int *ier);
   void FCV_SPGMRREINIT(int *pretype, int *gstype, realtype *delt, int *ier);
 
@@ -749,7 +902,8 @@ extern "C" {
 
   enum { CV_LS_DENSE = 1, CV_LS_BAND = 2, CV_LS_DIAG = 3,
          CV_LS_LAPACKDENSE = 4, CV_LS_LAPACKBAND = 5,
-	 CV_LS_SPGMR = 6, CV_LS_SPBCG = 7, CV_LS_SPTFQMR = 8 };
+	 CV_LS_KLU = 6, CV_LS_SUPERLUMT = 7, 
+	 CV_LS_SPGMR = 8, CV_LS_SPBCG = 9, CV_LS_SPTFQMR = 10 };
 
 #ifdef __cplusplus
 }
