@@ -1,14 +1,19 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.9 $
- * $Date: 2010/12/01 22:30:42 $
+ * $Revision: 4378 $
+ * $Date: 2015-02-19 10:55:14 -0800 (Thu, 19 Feb 2015) $
  * ----------------------------------------------------------------- 
  * Programmer(s): Radu Serban @ LLNL
  * -----------------------------------------------------------------
- * Copyright (c) 2005, The Regents of the University of California.
+ * LLNS Copyright Start
+ * Copyright (c) 2014, Lawrence Livermore National Security
+ * This work was performed under the auspices of the U.S. Department 
+ * of Energy by Lawrence Livermore National Laboratory in part under 
+ * Contract W-7405-Eng-48 and in part under Contract DE-AC52-07NA27344.
  * Produced at the Lawrence Livermore National Laboratory.
  * All rights reserved.
  * For details, see the LICENSE file.
+ * LLNS Copyright End
  * -----------------------------------------------------------------
  * Common implementation header file for the scaled, preconditioned
  * iterative linear solvers
@@ -18,13 +23,13 @@
 #ifndef _CVSSPILS_IMPL_H
 #define _CVSSPILS_IMPL_H
 
+#include <cvodes/cvodes_spils.h>
+#include "cvodes_impl.h"
+
 #ifdef __cplusplus  /* wrapper to enable C++ usage */
 extern "C" {
 #endif
 
-#include <cvodes/cvodes_spils.h>
-#include "cvodes_impl.h"
-
 /*
  * =================================================================
  * C V S P I L S    I N T E R N A L    C O N S T A N T S
@@ -143,8 +148,11 @@ int CVSpilsDQJtimes(N_Vector v, N_Vector Jv, realtype t,
 typedef struct CVSpilsMemRecB {
 
   CVSpilsJacTimesVecFnB s_jtimesB;
+  CVSpilsJacTimesVecFnBS s_jtimesBS;
   CVSpilsPrecSetupFnB s_psetB;
+  CVSpilsPrecSetupFnBS s_psetBS;
   CVSpilsPrecSolveFnB s_psolveB;
+  CVSpilsPrecSolveFnBS s_psolveBS;
   void *s_P_dataB;
 
 } *CVSpilsMemB;
