@@ -1,14 +1,19 @@
 /*
  * -----------------------------------------------------------------
- * $Revision: 1.11 $
- * $Date: 2010/12/01 22:43:33 $
+ * $Revision: 4397 $
+ * $Date: 2015-02-28 14:03:10 -0800 (Sat, 28 Feb 2015) $
  * ----------------------------------------------------------------- 
  * Programmer(s): Radu Serban @ LLNL
  * -----------------------------------------------------------------
- * Copyright (c) 2002, The Regents of the University of California.
+ * LLNS Copyright Start
+ * Copyright (c) 2014, Lawrence Livermore National Security
+ * This work was performed under the auspices of the U.S. Department 
+ * of Energy by Lawrence Livermore National Laboratory in part under 
+ * Contract W-7405-Eng-48 and in part under Contract DE-AC52-07NA27344.
  * Produced at the Lawrence Livermore National Laboratory.
  * All rights reserved.
  * For details, see the LICENSE file.
+ * LLNS Copyright End
  * -----------------------------------------------------------------
  * This is the implementation file for the KINDENSE linear solver.
  * -----------------------------------------------------------------
@@ -39,7 +44,7 @@
 static int kinDenseInit(KINMem kin_mem);
 static int kinDenseSetup(KINMem kin_mem);
 static int kinDenseSolve(KINMem kin_mem, N_Vector x, N_Vector b,
-                         realtype *res_norm);
+                         realtype *sJpnorm, realtype *sFdotJp);
 static void kinDenseFree(KINMem kin_mem);
 
 /*
@@ -63,14 +68,13 @@ static void kinDenseFree(KINMem kin_mem);
 #define uscale         (kin_mem->kin_uscale)
 #define fscale         (kin_mem->kin_fscale)
 #define sqrt_relfunc   (kin_mem->kin_sqrt_relfunc)
-#define sJpnorm        (kin_mem->kin_sJpnorm)
-#define sfdotJp        (kin_mem->kin_sfdotJp)
 #define errfp          (kin_mem->kin_errfp)
 #define infofp         (kin_mem->kin_infofp)
 #define setupNonNull   (kin_mem->kin_setupNonNull)
 #define vtemp1         (kin_mem->kin_vtemp1)
 #define vec_tmpl       (kin_mem->kin_vtemp1)
 #define vtemp2         (kin_mem->kin_vtemp2)
+#define strategy       (kin_mem->kin_globalstrategy)
 
 #define mtype          (kindls_mem->d_type)
 #define n              (kindls_mem->d_n)
@@ -222,6 +226,12 @@ static int kinDenseInit(KINMem kin_mem)
   } else {
     J_data = kin_mem->kin_user_data;
   }
+  
+  if ( (strategy == KIN_PICARD) && jacDQ ) {
+    KINProcessError(kin_mem, KIN_ILL_INPUT, "KINSOL", "KINDenseInit", 
+		    MSG_NOL_FAIL);
+    return(KIN_ILL_INPUT);
+  }
 
   last_flag = KINDLS_SUCCESS;
   return(0);
@@ -268,10 +278,12 @@ static int kinDenseSetup(KINMem kin_mem)
  * -----------------------------------------------------------------
  * This routine handles the solve operation for the dense linear solver
  * by calling the dense backsolve routine.  The returned value is 0.
+ * The argument *sJpnorm is ignored.
  * -----------------------------------------------------------------
  */
 
-static int kinDenseSolve(KINMem kin_mem, N_Vector x, N_Vector b, realtype *res_norm)
+static int kinDenseSolve(KINMem kin_mem, N_Vector x, N_Vector b,
+                         realtype *sJpnorm, realtype *sFdotJp)
 {
   KINDlsMem kindls_mem;
   realtype *xd;
@@ -288,23 +300,18 @@ static int kinDenseSolve(KINMem kin_mem, N_Vector x, N_Vector b, realtype *res_n
   
   DenseGETRS(J, lpivots, xd);
 
-  /* Compute the terms Jpnorm and sfdotJp for use in the global strategy
-     routines and in KINForcingTerm. Both of these terms are subsequently
-     corrected if the step is reduced by constraints or the line search.
+  /* Compute the term sFdotJp for use in the linesearch routine.
+     This term is subsequently corrected if the step is reduced by
+     constraints or the linesearch.
 
-     sJpnorm is the norm of the scaled product (scaled by fscale) of
-     the current Jacobian matrix J and the step vector p.
+     sFdotJp is the dot product of the scaled f vector and the scaled
+     vector J*p, where the scaling uses fscale.                            */
 
-     sfdotJp is the dot product of the scaled f vector and the scaled
-     vector J*p, where the scaling uses fscale. */
-
-  sJpnorm = N_VWL2Norm(b,fscale);
   N_VProd(b, fscale, b);
   N_VProd(b, fscale, b);
-  sfdotJp = N_VDotProd(fval, b);
+  *sFdotJp = N_VDotProd(fval, b);
 
   last_flag = KINDLS_SUCCESS;
-
   return(0);
 }
 
